<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("_d706c160e45bf743" . "4fff82a5976f0e19" => base64_decode("YXJyYXlfa2V5c" . "w=="), "_8c575917cbaedf1e7efae84939402" . "bff" => base64_decode("U3Vi" . "amVj" . "dA=="), "_6e1c717cf3cbf1af982ed74d433" . "6b7f1" => base64_decode("Ym9" . "keS" . "1od" . "G1s"), "_618a4aeb9" . "fecc4592a4" . "521f34876f" . "a29" => base64_decode("ZnJvbQ=" . "="), "_97ea09a7faf27" . "c52c6eff69773d" . "f1d8a" => base64_decode("dGltZXN0YW1" . "w"), "_956cd32298a" . "229f9768f109" . "6f077ace3" => base64_decode("Ym9keS1wbGF" . "pbg=="), "_9c050c786fc87170cbb84fc6a8b13c" . "b6" => base64_decode("YXR0YWNobWVudC" . "0="), "_a1e707d02a236" . "dadebd15a45e65" . "ebdb6" => base64_decode("YXR0YWNobWVud" . "C1jb3VudA=="), "_44e986c" . "04f41a08" . "b56a383c" . "7b3a88ee" . "2" => base64_decode("c2VuZG" . "Vy"), "_1d6c68a" . "0262e8fa" . "0bed1215" . "b7224a98" . "e" => base64_decode("cmVjaXBpZ" . "W50"), "_f589476007fa133f457c3ef29" . "ddfa566" => base64_decode("VG8" . "="), "_f39f5346e313e4dd1ac3a" . "7bd8032beda" => base64_decode("c3Vic3RyX2NvbXB" . "hcmU="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_d706c160e45bf74" . "34fff82a5976f0e1" . "9"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_a1e707d02a236dadebd15a45e65e" . "bdb6"] && $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_f39f5346" . "e313e4dd1" . "ac3a7bd80" . "32beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_9c050c786fc87170cbb84fc6a8b13" . "cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_1d6c68a02" . "62e8fa0bed" . "1215b7224a" . "98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_618a4aeb9fecc4592a4521f348" . "76fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_f589476007fa133f4" . "57c3ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_8c575917cbaedf1e" . "7efae84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_6e1c717cf3cbf" . "1af982ed74d433" . "6b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_956cd32298a22" . "9f9768f1096f07" . "7ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_97ea09a7faf27c52c6eff69773" . "df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_44e986c04f41a08b56a383c7b3a8" . "8ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}