<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array("_618a4aeb9fecc4592a" . "4521f34876fa29" => base64_decode("ZnJv" . "bQ=="), "_67a0d624aebcceb0abd5ce5" . "6a53ff06f" => base64_decode("ZG" . "F0" . "ZQ" . "=="), "_c35473364fa7a050299058f33" . "2ec29c1" => base64_decode("ZXh" . "jZX" . "B0a" . "W9u"), "_a3d82c5df38e194c9c73e3ccb422" . "3bbc" => base64_decode("ZW1haWx" . "fZGF0YQ" . "=="), "_f656816961e" . "8573806141c5" . "58b184fe2" => base64_decode("c3ViamV" . "jdA=="), "_376d30c40857357a4d4cbb1ffaa25" . "817" => base64_decode("dG8" . "="), "_03b1f0cee835582d1158dce" . "2678b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCByZWNlaXZlZCBzd" . "WJzY3JpYmVy"), "_bfda889b74ea561b14325e30e7d7542" . "6" => base64_decode("Ym9keV9odG1" . "s"), "_460e1aeb3113a1" . "676ce59a8f40431" . "d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9y" . "IGluZm9jYXB0dXJlIHByb2plY3Q="), "_5d40a2cf1c525fb252bf5" . "599e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdC" . "B3YXMgaWRlbnRpZmllZCBmb3IgbWFp" . "bDsgc3ViamVjdCAn"), "projec" . "t_id" => base64_decode("cHJvam" . "VjdF9p" . "ZA=="), "_ced92d7b391285c8a26846f1f4" . "bd3128" => base64_decode("Ym9keV90Z" . "Xh0"), "_e608e5b5c4c34a67ba9" . "7ef84c1e16199" => base64_decode("Jw" . "=="), "_9b16fa2683095e67d7" . "c8b265a8081d0b" => base64_decode("TWFpbFJlY2V" . "pdmVkRXZlbn" . "RSZWNlaXZlc" . "g=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_9b16fa2683095e67d7c" . "8b265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_03b1f0cee8" . "35582d1158d" . "ce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_5d40a2cf1c5" . "25fb252bf559" . "9e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_e608e5b5c4c34a6" . "7ba97ef84c1e1619" . "9"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_618a4aeb9fecc4592a" . "4521f34876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_376d30c40857357a4d4cb" . "b1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_f656816961e85738" . "06141c558b184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_ced92d7b391285c8a26846f1f4bd3" . "128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_bfda889" . "b74ea561" . "b14325e3" . "0e7d7542" . "6"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_67a0d624aebcceb0abd5ce56a53ff06" . "f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_460e1aeb31" . "13a1676ce59" . "a8f40431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["project_i" . "d"] => $project->GetId(), $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_a3d82c5df3" . "8e194c9c73e" . "3ccb4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_c35473364" . "fa7a050299" . "058f332ec2" . "9c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}